@@ -202,7 +202,6 @@ async fn test_flushing_backoff_and_metadata() {
             ))),
             log_event_url: Some(mock_scrapi.url_for_endpoint(Endpoint::LogEvent)),
             output_log_level: Some(LogLevel::Debug),
-            disable_user_agent_parsing: Some(true),
             disable_country_lookup: Some(true),
             ..StatsigOptions::new()
         })),
@@ -247,17 +246,13 @@ fn assert_flushing_interval_and_scheduled_batch(
 
     assert!(
         actual_interval >= expected_threshold_interval,
-        "Expected loggingInterval >= {}, but got {} at index {}",
-        expected_threshold_interval,
-        actual_interval,
-        index
+        "Expected loggingInterval >= {expected_threshold_interval}, but got {actual_interval} at index {index}"
     );
 
     assert_eq!(
         statsig_metadata.get("flushType").and_then(|v| v.as_str()),
         Some("scheduled:max_time"),
-        "Unexpected flushType to be 'scheduled' at index {}",
-        index
+        "Unexpected flushType to be 'scheduled' at index {index}"
     );
 }
 
